@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 2005 Jim Jozwiak.
+    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ struct meal *meal_ptr;
 int max, meals, count, mealcount, meal = 0, deficnuts;
 int i, abacuscount, spacecount = 0, frcount, high_grams;
 char meal_date[9], inbuf[128];
-float newcal;
+float newcal, ccals, fcals;
 float deficpct[DV_COUNT], food_abacus[MAX_FOOD], serving_ratio_abacus[MAX_FOOD];
 int deficnut[DV_COUNT];
 float prodefic, thispct, totaldefic, serving_ratio;
@@ -104,10 +104,52 @@ while (max > 0)
    newcal = food_work.nutrient[ENERC_KCAL];
    options.abnuts[FAT] = 0;
    options.abnuts[FAMS] = 0;
+   if (strstr(inbuf,"/") != NULL)
+    {
+    ccals = 0;
+    fcals = 0;
+    ccals = atof(inbuf+2);
+    if (ccals > 0 && strstr(inbuf+2,"/") != NULL)
+     {
+     fcals = atof(strchr(inbuf+2,'/')+1);
+     if (fcals > 0)
+     newcal -= food_work.nutrient[CHO_KCAL] - ccals + food_work.nutrient[FAT_KCAL] - fcals;
+      {
+      if (!options.locknuts[CHOCDF])
+       {
+       options.abnuts[CHOCDF] = 0;
+       options.pccarb = 100 * ccals / newcal;
+       }
+      if (!options.locknuts[PROCNT])
+       {
+       options.abnuts[PROCNT] = 0;
+       options.pcprotein = 100 * food_work.nutrient[PROT_KCAL] / newcal;
+       }
+      if (!options.locknuts[FIBTG]) options.abnuts[FIBTG] = food_work.nutrient[FIBTG] * ccals / food_work.nutrient[CHO_KCAL];
+      }
+     }
+    if (ccals > 0 && strstr(inbuf+2,"/") == NULL)
+     {
+     newcal -= food_work.nutrient[CHO_KCAL] - ccals;
+     if (!options.locknuts[CHOCDF])
+      {
+      options.abnuts[CHOCDF] = 0;
+      options.pccarb = 100 * ccals / newcal;
+      }
+     if (!options.locknuts[PROCNT])
+      {
+      options.abnuts[PROCNT] = 0;
+      options.pcprotein = 100 * food_work.nutrient[PROT_KCAL] / newcal;
+      }
+     if (!options.locknuts[FIBTG]) options.abnuts[FIBTG] = food_work.nutrient[FIBTG] * ccals / food_work.nutrient[CHO_KCAL];
+     }
+    }
+   if (options.fatprotratio > 0 && options.abnuts[PROCNT]) options.pccarb = 0;
    auto_cal(&newcal,1);
    }
   } 
  else if (strncmp(inbuf,"d",1) == 0) screen();
+ else if (strncmp(inbuf,"p",1) == 0) screen_previous();
  else if (strncmp(inbuf,"e",1) == 0 )
   {
   if ( !options.locknuts[PROCNT] ) options.pcprotein = 0 ;
@@ -155,15 +197,19 @@ while (max > 0)
    {
    newcal = food_work.nutrient[ENERC_KCAL];
    if ( !options.locknuts[PROCNT]) options.pcprotein = food_work.nutrient[PROT_KCAL] / food_work.nutrient[ENERC_KCAL] * 100;
-   if ( !options.locknuts[PROCNT]) options.pccarb = food_work.nutrient[CHO_KCAL] / food_work.nutrient[ENERC_KCAL] * 100;
+   if ( !options.locknuts[CHOCDF]) options.pccarb = food_work.nutrient[CHO_KCAL] / food_work.nutrient[ENERC_KCAL] * 100;
    }
   if (  options.locknuts[ENERC_KCAL])
    {
    newcal = DV[ENERC_KCAL];
    if ( !options.locknuts[PROCNT]) options.pcprotein = food_work.nutrient[PROT_KCAL] / DV[ENERC_KCAL] * 100;
-   if ( !options.locknuts[PROCNT]) options.pccarb = food_work.nutrient[CHO_KCAL] / DV[ENERC_KCAL] * 100;
+   if ( !options.locknuts[CHOCDF]) options.pccarb = food_work.nutrient[CHO_KCAL] / DV[ENERC_KCAL] * 100;
+   }
+  if ( options.fatprotratio > 0 && ( options.pcprotein > 0 || options.abnuts[PROCNT] > 0) )
+   {
+   options.pccarb = 0;
+   options.abnuts[CHOCDF] = 0;
    }
-  if ( options.fatprotratio > 0 && ( options.pcprotein > 0 || options.abnuts[PROCNT] > 0) ) options.abnuts[CHOCDF] = 0;
   auto_cal(&newcal,1);
   }
  else if (strncmp(inbuf,"o",1) == 0 ) restore_defaults(0);
