@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 2005 Jim Jozwiak.
+    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -42,14 +42,15 @@ CA,CU,FE,MG,MN,P,K,SE,NA,ZN
 
 int CarbAminoMap[] =
 {
-32,CHOCDF,FIBTG,STARCH,SUGAR,FRUS,GALS,GLUS,LACS,MALS,SUCS,ALC,
+31,CHOCDF,FIBTG,STARCH,SUGAR,FRUS,GALS,GLUS,LACS,MALS,SUCS,
 PROCNT,ADPROT,ALA_G,ARG_G,ASP_G,CYS_G,GLU_G,GLY_G,HISTN_G,HYP,ILE_G,
 LEU_G,LYS_G,MET_G,PHE_G,PRO_G,SER_G,THR_G,TRP_G,TYR_G,VAL_G
 };
 
 int MiscMap[] =
 {
-24,ENERC_KJ,ASH,WATER,CAFFN,THEBRN,FOLAC,FOLFD,FOLDFE,RETOL,VITA_RAE,
+27,ENERC_KJ,ASH,WATER,CAFFN,THEBRN,ALC,FOLAC,FOLFD,FOLDFE,RETOL,VITA_RAE,
+VITB12_ADDED,VITE_ADDED,
 TOCPHA,TOCPHB,TOCPHG,TOCPHD,CARTA,CARTB,CRYPX,LUT_ZEA,LYCPN,
 CHOLE,PHYSTR,SITSTR,CAMD5,STID7
 };
@@ -62,10 +63,10 @@ F17D0,F18D0,F20D0,F22D0,F24D0
 
 int UnsatMap[] =
 {
-34,FAMS,F14D1,F15D1,F16D1,F16D1C,F17D1,F18D1,F18D1C,F20D1,F22D1,F22D1C,F24D1C,
-FAPU,F18D2,F18D2CN6,F18D3,F18D3CN3,F18D3CN6,F18D4,F20D2CN6,F20D3,
-F20D4,F20D5,F22D5,F22D6,
-FATRN,FATRNM,F16D1T,F18D1T,FATRNP,F18D2T,F18D2I,F18D2CLA,F18D3I
+40,FAMS,F14D1,F15D1,F16D1,F16D1C,F17D1,F18D1,F18D1C,F20D1,F22D1,F22D1C,F24D1C,
+FAPU,F18D2,F18D2CN6,F18D3,F18D3CN3,F18D3CN6,F18D4,F20D2CN6,F20D3,F20D3N6,
+F20D4,F20D4N6,F20D5,F21D5,F22D4,F22D5,F22D6,
+FATRN,FATRNM,F16D1T,F18D1T,F22D1T,FATRNP,F18D2T,F18D2TT,F18D2I,F18D2CLA,F18D3I
 };
 
 int *ScreenMap[] =
@@ -130,12 +131,12 @@ DVBase[VITC] = 60;
 DVBase[FASAT] = 20;
 DVBase[CHOLE] = 300;
 DVBase[VITD] = 400;
-DVBase[LA] = 18.8;
-DVBase[AA] = 0.27;
+DVBase[LA] = 9;
+DVBase[AA] = 0.25;
 DVBase[OMEGA6] = DVBase[LA] + DVBase[AA];
-DVBase[ALA] = 3.22;
-DVBase[EPA] = 0.37;
-DVBase[DHA] = 0.37;
+DVBase[ALA] = 2.5;
+DVBase[EPA] = 0.25;
+DVBase[DHA] = 0.25;
 DVBase[OMEGA3] = DVBase[ALA] + DVBase[EPA] + DVBase[DHA];
 DVBase[FAPU] = DVBase[OMEGA6] + DVBase[OMEGA3];
 DVBase[FAMS] = 61.5 - DVBase[FASAT] - DVBase[FAPU];
@@ -590,6 +591,9 @@ if (food_work.nutrient[ENERC_KCAL] > 0.05)
  pctcarb = 100 * food_work.nutrient[CHO_KCAL] / food_work.nutrient[ENERC_KCAL];
  pctprot = 100 * food_work.nutrient[PROT_KCAL] / food_work.nutrient[ENERC_KCAL]; 
  pctfat = 100 * food_work.nutrient[FAT_KCAL] / food_work.nutrient[ENERC_KCAL];
+ if (test_for_negative_zero(&pctcarb)) pctcarb = 0;
+ if (test_for_negative_zero(&pctprot)) pctprot = 0;
+ if (test_for_negative_zero(&pctfat)) pctfat = 0;
  }
 else
  {
@@ -641,14 +645,20 @@ switch (options.screen)
  case 2 :
  fprintf(fp,"%-27s","Carbohydrates");
  fprintf(fp,"%-27s\n\n","Amino Acids");
- for (i = 1; i < 11 ; i++)
+ for (i = 1; i < 5 ; i++)
   {
   food_display_line(fp,ScreenMap[options.screen][i],0,0,0,0);
-  food_display_line(fp,ScreenMap[options.screen][i+11],0,0,0,0);
-  food_display_line(fp,ScreenMap[options.screen][i+22],0,1,0,0);
+  food_display_line(fp,ScreenMap[options.screen][i+10],0,0,0,0);
+  food_display_line(fp,ScreenMap[options.screen][i+21],0,1,0,0);
   }
- food_display_line(fp,ScreenMap[options.screen][i],0,0,0,0);
- food_display_line(fp,ScreenMap[options.screen][i+11],0,1,0,0);
+ for (i = 5; i < 11 ; i++)
+  {
+  food_display_line(fp,ScreenMap[options.screen][i],0,0,0,1);
+  food_display_line(fp,ScreenMap[options.screen][i+10],0,0,0,0);
+  food_display_line(fp,ScreenMap[options.screen][i+21],0,1,0,0);
+  }
+ fprintf(fp,"%-27s"," ");
+ food_display_line(fp,ScreenMap[options.screen][i+10],0,1,0,0);
  fprintf(fp,"\n\n");
  break;
  case 3 :
@@ -656,16 +666,15 @@ switch (options.screen)
  for (i = 1; i < 6 ; i++)
   {
   food_display_line(fp,ScreenMap[options.screen][i],0,0,0,0);
-  food_display_line(fp,ScreenMap[options.screen][i+10],0,0,0,0);
-  food_display_line(fp,ScreenMap[options.screen][i+19],0,1,0,0);
+  food_display_line(fp,ScreenMap[options.screen][i+13],0,0,0,0);
+  food_display_line(fp,ScreenMap[options.screen][i+22],0,1,0,0);
   }
  for (i = 6; i < 10 ; i++)
   {
   food_display_line(fp,ScreenMap[options.screen][i],0,0,0,0);
-  food_display_line(fp,ScreenMap[options.screen][i+10],0,1,0,0);
+  food_display_line(fp,ScreenMap[options.screen][i+13],0,1,0,0);
   }
- food_display_line(fp,ScreenMap[options.screen][i],0,1,0,0);
- fprintf(fp,"\n\n\n");
+ for (i = 10; i <= 13 ; i++) food_display_line(fp,ScreenMap[options.screen][i],0,1,0,0);
  break;
  case 4 :
  fprintf(fp,"Saturated Fatty Acids\n\n");
@@ -680,23 +689,20 @@ switch (options.screen)
  case 5 :
  fprintf(fp,"%-27s","Unsaturated Fatty Acids");
  food_display_line(fp,ScreenMap[options.screen][13],0,0,1,0);
- food_display_line(fp,ScreenMap[options.screen][26],0,1,1,0);
+ food_display_line(fp,ScreenMap[options.screen][28],0,1,1,0);
  fprintf(fp,"%-27s"," ");
  food_display_line(fp,ScreenMap[options.screen][14],0,0,1,0);
- food_display_line(fp,ScreenMap[options.screen][27],0,1,1,0);
- for (i = 1; i < 8 ; i++)
+ food_display_line(fp,ScreenMap[options.screen][29],0,1,1,0);
+ food_display_line(fp,ScreenMap[options.screen][1],0,0,1,0);
+ food_display_line(fp,ScreenMap[options.screen][15],0,1,1,0);
+ for (i = 2; i < 13 ; i++)
   {
   food_display_line(fp,ScreenMap[options.screen][i],0,0,1,0);
   food_display_line(fp,ScreenMap[options.screen][i+14],0,0,1,0);
-  food_display_line(fp,ScreenMap[options.screen][i+27],0,1,1,0);
+  food_display_line(fp,ScreenMap[options.screen][i+28],0,1,1,0);
   }
- for (i = 8; i < 12 ; i++)
-  {
-  food_display_line(fp,ScreenMap[options.screen][i],0,0,1,0);
-  food_display_line(fp,ScreenMap[options.screen][i+14],0,1,1,0);
-  }
- food_display_line(fp,ScreenMap[options.screen][i],0,0,1,0);
- fprintf(fp,"\n\n");
+ fprintf(fp,"%-27s"," ");
+ food_display_line(fp,ScreenMap[options.screen][27],0,1,1,0);
  break;
  default :
  if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][1]])) fprintf(fp,"Calories(%4.0f)   %5.0f%%     ",DV[ScreenMap[options.screen][1]],food_work.nutrient[ScreenMap[options.screen][1]]/DV[ScreenMap[options.screen][1]]*100);
@@ -717,7 +723,7 @@ switch (options.screen)
  food_display_line(fp,ScreenMap[options.screen][3],1,0,0,1);
  food_display_line(fp,ScreenMap[options.screen][19],1,0,0,0);
  food_display_line(fp,ScreenMap[options.screen][31],1,1,0,0);
- if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][4]])) fprintf(fp," %-13s   %5.0f%%     ",Nutrient[ScreenMap[options.screen][4]],food_work.nutrient[ScreenMap[options.screen][4]]/dv_fams()*100);
+ if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][4]])) fprintf(fp," %-13s   %5.0f%%     ",Nutrient[ScreenMap[options.screen][4]],food_work.nutrient[ScreenMap[options.screen][4]]/DV[FAMS]*100);
  else fprintf(fp," %-13s    %5s     ",Nutrient[ScreenMap[options.screen][4]],"(nd)");
  food_display_line(fp,ScreenMap[options.screen][20],1,0,0,0);
  food_display_line(fp,ScreenMap[options.screen][32],1,1,0,0);
@@ -781,7 +787,7 @@ switch (flags)
   if (! test_for_negative_zero(&food_work.nutrient[nut])) fprintf(fp,"%8.1f %-3s\n",food_work.nutrient[nut],Unit[nut]);
   else fprintf(fp,"%9s%-3s\n","(nd)"," ");
 #else
-  if (nut != VITE && nut != VITK && nut != ILE_G && nut != CARTB && nut != CRYPX && nut != LUT_ZEA && nut != LYCPN && nut != VITA_RAE && nut != F14D0)
+  if (nut != VITE && nut != VITK && nut != ILE_G && nut != CARTB && nut != CRYPX && nut != LUT_ZEA && nut != LYCPN && nut != VITA_RAE && nut != RETOL && nut != VITA_RAE && nut != VITB12_ADDED && nut != VITE_ADDED && nut != F14D0)
    {
    if (! test_for_negative_zero(&food_work.nutrient[nut])) fprintf(fp,"%7.1f %-3s\n",food_work.nutrient[nut],Unit[nut]);
    else fprintf(fp,"%8s%-3s\n","(nd)"," ");
@@ -798,7 +804,7 @@ switch (flags)
   if (! test_for_negative_zero(&food_work.nutrient[nut])) fprintf(fp,"%8.2f %-3s\n",food_work.nutrient[nut],Unit[nut]);
   else fprintf(fp,"%9s%-3s\n","(nd)"," ");
 #else
-  if (nut != F20D2CN6 && nut != F20D3 && nut != F20D4 && nut != F20D5 && nut != F22D5 && nut != F22D6)
+  if (nut != F18D2CN6 && nut != F20D2CN6 && nut != F20D3 && nut != F20D4 && nut != F20D5 && nut != F22D4)
    {
    if (! test_for_negative_zero(&food_work.nutrient[nut])) fprintf(fp,"%7.2f %-3s\n",food_work.nutrient[nut],Unit[nut]);
    else fprintf(fp,"%8s%-3s\n","(nd)"," ");
@@ -829,18 +835,24 @@ new_recipe->next = NULL;
 food_ptr->next = new_recipe;
 }
 
-void delete_recipe_food(int num)
+void modify_recipe_food(int num, char *qty)
 {
 struct food *m, *recipe_ptr = &recipe_root;
 int count = 0;
+float newqty;
 while (recipe_ptr->next != NULL)
  {
  count++;
  if (count == num)
   {
-  m = recipe_ptr->next;
-  recipe_ptr->next = recipe_ptr->next->next;
-  free(m);
+  newqty = evaluate_qty(food_number(recipe_ptr->next->food_no),qty);
+  if (newqty == 0)
+   {
+   m = recipe_ptr->next;
+   recipe_ptr->next = recipe_ptr->next->next;
+   free(m);
+   }
+  else recipe_ptr->next->grams = newqty;
   return;
   }
  recipe_ptr = recipe_ptr->next;
@@ -892,18 +904,6 @@ food_ptr->nutrient[CHO_NONFIB] = food_ptr->nutrient[CHOCDF] - food_ptr->nutrient
 if (food_ptr->nutrient[CHO_NONFIB] < 0) food_ptr->nutrient[CHO_NONFIB] = 0;
 }
 
-float dv_fams()
-{
-float targetpct, totalfa, totaldv, imaginarydv, diff;
-targetpct = dv_fat() / 100;
-totalfa = food_work.nutrient[FASAT] + food_work.nutrient[FAMS] + food_work.nutrient[FAPU];
-totaldv = DV[FASAT] + DV[FAMS] + DV[FAPU];
-imaginarydv = totalfa / targetpct;
-diff = totaldv - imaginarydv;
-if (DV[FAMS] > diff) return DV[FAMS] - diff;
-else return DV[FAMS];
-}
-
 float dv_fat()
 {
 float targetpct, totalcal, totaldv, imaginarydv, diff;
@@ -914,8 +914,8 @@ if (options.pccarb == 0 && options.pcprotein == 0)
  totaldv = DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm + DV[FAT] * options.fatcalpergm;
  imaginarydv = totalcal / targetpct;
  diff = (totaldv - imaginarydv) / options.fatcalpergm;
- if (DV[FAT] > diff) return DV[FAT] - diff;
- else return DV[FAT];
+ if (DV[FAT] > diff) return food_work.nutrient[FAT] / (DV[FAT] - diff) * 100;
+ else return food_work.nutrient[FAT] / DV[FAT] * 100;
  }
 else return diff = 100 * food_work.nutrient[FAT_KCAL] / (DV[ENERC_KCAL] * (1 - (options.pccarb > 0 ? options.pccarb / 100 : DV[CHOCDF] * options.carbcalpergm / DV[ENERC_KCAL]) - (options.pcprotein > 0 ? options.pcprotein / 100 : DV[PROCNT] * options.protcalpergm / DV[ENERC_KCAL])));
 }
