@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 2005 Jim Jozwiak.
+    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -93,73 +93,81 @@
 #define PRO_G 71
 #define SER_G 72
 #define HYP 73
-#define CHOLE 74
-#define FATRN 75
-#define FASAT 76
-#define F4D0 77
-#define F6D0 78
-#define F8D0 79
-#define F10D0 80
-#define F12D0 81
-#define F14D0 82
-#define F16D0 83
-#define F18D0 84
-#define F20D0 85
-#define F18D1 86
-#define F18D2 87
-#define F18D3 88
-#define F20D4 89
-#define F22D6 90
-#define F22D0 91
-#define F14D1 92
-#define F16D1 93
-#define F18D4 94
-#define F20D1 95
-#define F20D5 96
-#define F22D1 97
-#define F22D5 98
-#define PHYSTR 99
-#define STID7 100
-#define CAMD5 101
-#define SITSTR 102
-#define FAMS 103
-#define FAPU 104
-#define F15D0 105
-#define F17D0 106
-#define F24D0 107
-#define F16D1T 108
-#define F18D1T 109
-#define F18D2T 110
-#define F18D2I 111
-#define F18D2CLA 112
-#define F24D1C 113
-#define F20D2CN6 114
-#define F16D1C 115
-#define F18D1C 116
-#define F18D2CN6 117
-#define F22D1C 118
-#define F18D3CN6 119
-#define F17D1 120
-#define F20D3 121
-#define FATRNM 122
-#define FATRNP 123
-#define F13D0 124
-#define F15D1 125
-#define F18D3CN3 126
-#define F18D3I 127
-#define PROT_KCAL 128
-#define FAT_KCAL 129
-#define CHO_KCAL 130
-#define CHO_NONFIB 131
-#define LA 132
-#define AA 133
-#define ALA 134
-#define EPA 135
-#define DHA 136
-#define OMEGA6 137
-#define OMEGA3 138
-#define VITE 139
+#define VITE_ADDED 74
+#define VITB12_ADDED 75
+#define CHOLE 76
+#define FATRN 77
+#define FASAT 78
+#define F4D0 79
+#define F6D0 80
+#define F8D0 81
+#define F10D0 82
+#define F12D0 83
+#define F14D0 84
+#define F16D0 85
+#define F18D0 86
+#define F20D0 87
+#define F18D1 88
+#define F18D2 89
+#define F18D3 90
+#define F20D4 91
+#define F22D6 92
+#define F22D0 93
+#define F14D1 94
+#define F16D1 95
+#define F18D4 96
+#define F20D1 97
+#define F20D5 98
+#define F22D1 99
+#define F22D5 100
+#define PHYSTR 101
+#define STID7 102
+#define CAMD5 103
+#define SITSTR 104
+#define FAMS 105
+#define FAPU 106
+#define F15D0 107
+#define F17D0 108
+#define F24D0 109
+#define F16D1T 110
+#define F18D1T 111
+#define F22D1T 112
+#define F18D2T 113
+#define F18D2I 114
+#define F18D2TT 115
+#define F18D2CLA 116
+#define F24D1C 117
+#define F20D2CN6 118
+#define F16D1C 119
+#define F18D1C 120
+#define F18D2CN6 121
+#define F22D1C 122
+#define F18D3CN6 123
+#define F17D1 124
+#define F20D3 125
+#define FATRNM 126
+#define FATRNP 127
+#define F13D0 128
+#define F15D1 129
+#define F18D3CN3 130
+#define F20D3N6 131
+#define F20D4N6 132
+#define F18D3I 133
+#define F21D5 134
+#define F22D4 135
+#define PROT_KCAL 136
+#define FAT_KCAL 137
+#define CHO_KCAL 138
+#define CHO_NONFIB 139
+#define LA 140
+#define AA 141
+#define ALA 142
+#define EPA 143
+#define DHA 144
+#define OMEGA6 145
+#define OMEGA3 146
+#define VITE 147
 
-#define NUTRIENT_COUNT 140
+#define NUTRIENT_COUNT 148
 #define DERIVED 12
-#define NUTRNO_ARRAYSIZE 857
+#define NUTRNO_ARRAYSIZE 859
