@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 2005 Jim Jozwiak.
+    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -361,6 +361,14 @@ options.screen %= MaxScreen;
 write_OPTIONS();
 }
 
+void screen_previous(void)
+{
+    if (--options.screen < 0) {
+        options.screen = MaxScreen - 1;
+    }
+    write_OPTIONS();
+}
+
 void get_cals(float *cals)
 {
 char buff[128];
@@ -370,7 +378,7 @@ fgets(buff,128,stdin);
 
 void auto_cal(float *bufptr, int analflag)
 {
-float buf = *bufptr, temp = 0;
+float buf = *bufptr, temp = 0, temp1 = 0;
 int i;
 if (options.autocal) buf = average_cals(analflag);
 if (analflag)
@@ -395,7 +403,7 @@ if (buf != 1)
  {
  DV[PROCNT] = buf * DVBase[PROCNT] * 4 / options.protcalpergm;
  DV[FAT] = buf * DVBase[FAT] * 9.2307692 / options.fatcalpergm;
- DV[CHOCDF] = buf * DVBase[CHOCDF] * 4 / options.carbcalpergm;;
+ DV[CHOCDF] = buf * DVBase[CHOCDF] * 4 / options.carbcalpergm;
  }
 if (buf == 1)
  {
@@ -488,10 +496,20 @@ if (options.abnuts[ZN] > 0) DV[ZN] = options.abnuts[ZN];
 if (! options.abnuts[CHO_NONFIB]) DV[CHO_NONFIB] = DV[CHOCDF] - DV[FIBTG] < 0 ? 0 : DV[CHOCDF] - DV[FIBTG];
 else DV[CHO_NONFIB] = options.abnuts[CHO_NONFIB];
 temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
+if (temp > .32 && options.locknuts[LA] == 0 && options.locknuts[AA] == 0 && options.locknuts[OMEGA6] == 0 && options.locknuts[FAPU] == 0 && options.abnuts[LA] == 0 && options.abnuts[AA] == 0 && options.abnuts[OMEGA6] == 0 && options.abnuts[FAPU] == 0 ) 
+ {
+ temp1 = ((temp / .3) - 1);
+ DV[FAMS] -= temp1 * (DV[LA] + DV[ALA]);
+ DV[FAPU] += temp1 * (DV[LA] + DV[ALA]);
+ DV[OMEGA6] += temp1 * DV[LA];
+ DV[LA] += temp1 * DV[LA];
+ DV[OMEGA3] += temp1 * DV[ALA];
+ DV[ALA] += temp1 * DV[ALA];
+ }
 if (temp > .32 && options.pcsatfat <= 0 && options.abnuts[FASAT] <= 0 && options.abnuts[FAMS] <= 0) 
  {
  temp = DV[FAMS] + DV[FASAT];
- DV[FASAT] = 0.42 * temp;
+ DV[FASAT] = 0.4 * temp;
  DV[FAMS] = temp - DV[FASAT];
  }
 if ( options.pcsatfat > 0 || options.pcprotein > 0 || options.pccarb > 0 || options.fatprotratio || options.abnuts[PROCNT] > 0 || options.abnuts[CHOCDF] > 0 || options.abnuts[FIBTG] > 0 || options.abnuts[VITE]) options.custom = 1;
