@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 2005 Jim Jozwiak.
+    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,8 +38,10 @@ char meal_date[9];
 char new_meal_date[9];
 char theusual_id[9];
 char substring[61];
+char buff[61];
 char key[61];
-int meal = 0, delfood, junk;
+char *token;
+int meal = 0, modfood, junk;
 float ratio = 0, one = 1;
 key[0] = '\0';
 today(meal_date);
@@ -92,9 +94,12 @@ for ( ; ; )
   if (( strcmp(key,".") == 0 || strcmp(key,",") == 0 )) analyze_meals(prev_meal(meal_find(meal_date,meal)),1);
   else
    {
-   delfood = atoi(key);
-   if (strcmp(key,"") == 0 || delfood == 0) break;
-   delete_meal(meal_date,meal,delfood);
+   modfood = atoi(key);
+   strncpy(buff,key,128);
+   token = strtok(buff, ", ");
+   token = strtok(NULL,", ");
+   if (strcmp(key,"") == 0 || modfood == 0) break;
+   modify_meal(meal_date,meal,modfood,token);
    write_meal_db();
    strcpy(key,"");
    }
